OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Cannot write into \"config\" directory!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "This can usually be fixed by giving the webserver write access to the config directory",
    "See %s" : "See %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "This can usually be fixed by %sgiving the webserver write access to the config directory%s.",
    "Sample configuration detected" : "Sample configuration detected",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php",
    "PHP %s or higher is required." : "PHP %s or higher is required.",
    "PHP with a version lower than %s is required." : "PHP with a version lower than %s is required.",
    "%sbit or higher PHP required." : "%sbit or higher PHP required.",
    "Following databases are supported: %s" : "Following databases are supported: %s",
    "The command line tool %s could not be found" : "The command line tool %s could not be found",
    "The library %s is not available." : "The library %s is not available.",
    "Library %s with a version higher than %s is required - available version %s." : "Library %s with a version higher than %s is required - available version %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Library %s with a version lower than %s is required - available version %s.",
    "Following platforms are supported: %s" : "Following platforms are supported: %s",
    "ownCloud %s or higher is required." : "ownCloud %s or higher is required.",
    "ownCloud %s or lower is required." : "ownCloud %s or lower is required.",
    "Unknown filetype" : "Unknown filetype",
    "Invalid image" : "Invalid image",
    "today" : "today",
    "yesterday" : "yesterday",
    "_%n day ago_::_%n days ago_" : ["%n day ago","%n days ago"],
    "last month" : "last month",
    "_%n month ago_::_%n months ago_" : ["%n month ago","%n months ago"],
    "last year" : "last year",
    "_%n year ago_::_%n years ago_" : ["%n year ago","%n years ago"],
    "_%n hour ago_::_%n hours ago_" : ["%n hour ago","%n hours ago"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minute ago","%n minutes ago"],
    "seconds ago" : "seconds ago",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator.",
    "Empty filename is not allowed" : "Empty filename is not allowed",
    "Dot files are not allowed" : "Dot files are not allowed",
    "4-byte characters are not supported in file names" : "4-byte characters are not supported in file names",
    "File name is a reserved word" : "File name is a reserved word",
    "File name contains at least one invalid character" : "File name contains at least one invalid character",
    "File name is too long" : "File name is too long",
    "App directory already exists" : "App directory already exists",
    "Can't create app folder. Please fix permissions. %s" : "Can't create app folder. Please fix permissions. %s",
    "Archive does not contain a directory named %s" : "Archive does not contain a directory named %s",
    "No source specified when installing app" : "No source specified when installing app",
    "No href specified when installing app from http" : "No href specified when installing app from http",
    "No path specified when installing app from local file" : "No path specified when installing app from local file",
    "Archives of type %s are not supported" : "Archives of type %s are not supported",
    "Failed to open archive when installing app" : "Failed to open archive when installing app",
    "App does not provide an info.xml file" : "App does not provide an info.xml file",
    "App cannot be installed because appinfo file cannot be read." : "App cannot be installed because appinfo file cannot be read.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Signature could not get checked. Please contact the app developer and check your admin screen.",
    "App can't be installed because of not allowed code in the App" : "App can't be installed because of unallowed code in the App",
    "App can't be installed because it is not compatible with this version of ownCloud" : "App can't be installed because it is not compatible with this version of ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "App can't be installed because the version in info.xml is not the same as the version reported from the app store",
    "%s enter the database username and name." : "%s enter the database username and name.",
    "%s enter the database username." : "%s enter the database username.",
    "%s enter the database name." : "%s enter the database name.",
    "%s you may not use dots in the database name" : "%s you may not use dots in the database name",
    "Oracle connection could not be established" : "Oracle connection could not be established",
    "Oracle username and/or password not valid" : "Oracle username and/or password not valid",
    "DB Error: \"%s\"" : "DB Error: \"%s\"",
    "Offending command was: \"%s\"" : "Offending command was: \"%s\"",
    "You need to enter either an existing account or the administrator." : "You need to enter either an existing account or the administrator.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Offending command was: \"%s\", name: %s, password: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL username and/or password not valid",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! ",
    "For the best results, please consider using a GNU/Linux server instead." : "For the best results, please consider using a GNU/Linux server instead.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir setting has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP.",
    "Set an admin username." : "Set an admin username.",
    "Set an admin password." : "Set an admin password.",
    "Can't create or write into the data directory %s" : "Can't create or write into the data directory %s",
    "Invalid Federated Cloud ID" : "Invalid Federated Cloud ID",
    "%s shared »%s« with you" : "%s shared \"%s\" with you",
    "%s via %s" : "%s via %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Sharing %s failed, because the backend does not allow shares from type %i",
    "Sharing %s failed, because the file does not exist" : "Sharing %s failed, because the file does not exist",
    "You are not allowed to share %s" : "You are not allowed to share %s",
    "Sharing %s failed, because you can not share with yourself" : "Sharing %s failed, because you can not share with yourself",
    "Sharing %s failed, because the user %s does not exist" : "Sharing %s failed, because the user %s does not exist",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of",
    "Sharing %s failed, because this item is already shared with %s" : "Sharing %s failed, because this item is already shared with %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Sharing %s failed, because this item is already shared with user %s",
    "Sharing %s failed, because the group %s does not exist" : "Sharing %s failed, because the group %s does not exist",
    "Sharing %s failed, because %s is not a member of the group %s" : "Sharing %s failed, because %s is not a member of the group %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "You need to provide a password to create a public link, only protected links are allowed",
    "Sharing %s failed, because sharing with links is not allowed" : "Sharing %s failed, because sharing with links is not allowed",
    "Not allowed to create a federated share with the same user" : "Not allowed to create a federated share with the same user",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Sharing %s failed, could not find %s, maybe the server is currently unreachable.",
    "Share type %s is not valid for %s" : "Share type %s is not valid for %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Setting permissions for %s failed, because the permissions exceed permissions granted to %s",
    "Setting permissions for %s failed, because the item was not found" : "Setting permissions for %s failed, because the item was not found",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Cannot set expiry date. Shares cannot expire later than %s after they have been shared",
    "Cannot set expiration date. Expiration date is in the past" : "Cannot set expiry date. Expiry date is in the past",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Cannot clear expiration date. Shares are required to have an expiration date.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Sharing backend %s must implement the interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Sharing backend %s not found",
    "Sharing backend for %s not found" : "Sharing backend for %s not found",
    "Sharing failed, because the user %s is the original sharer" : "Sharing failed, because the user %s is the original sharer",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Sharing %s failed, because the permissions exceed permissions granted to %s",
    "Sharing %s failed, because resharing is not allowed" : "Sharing %s failed, because resharing is not allowed",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Sharing %s failed, because the sharing backend for %s could not find its source",
    "Sharing %s failed, because the file could not be found in the file cache" : "Sharing %s failed, because the file could not be found in the file cache",
    "Cannot increase permissions of %s" : "Cannot increase permissions of %s",
    "Files can't be shared with delete permissions" : "Files can't be shared with delete permissions",
    "Files can't be shared with create permissions" : "Files can't be shared with create permissions",
    "Expiration date is in the past" : "Expiration date is in the past",
    "Cannot set expiration date more than %s days in the future" : "Cannot set expiration date more than %s days in the future",
    "Could not find category \"%s\"" : "Could not find category \"%s\"",
    "Apps" : "Apps",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "A valid username must be provided",
    "Username contains whitespace at the beginning or at the end" : "Username contains whitespace at the beginning or at the end",
    "A valid password must be provided" : "A valid password must be provided",
    "The username is already being used" : "The username is already being used",
    "Login canceled by app" : "Login cancelled by app",
    "User disabled" : "User disabled",
    "Help" : "Help",
    "Personal" : "Personal",
    "Users" : "Users",
    "Admin" : "Admin",
    "Recommended" : "Recommended",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "App \"%s\" cannot be installed because appinfo file cannot be read.",
    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud.",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s",
    "No app name specified" : "No app name specified",
    "web services under your control" : "web services under your control",
    "File is currently busy, please try again later" : "File is currently busy, please try again later",
    "Can't read file" : "Can't read file",
    "Application is not enabled" : "Application is not enabled",
    "Authentication error" : "Authentication error",
    "Token expired. Please reload page." : "Token expired. Please reload page.",
    "Unknown user" : "Unknown user",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No database drivers (sqlite, mysql, or postgresql) installed.",
    "Microsoft Windows Platform is not supported" : "Microsoft Windows Platform is not supported",
    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>.",
    "Cannot write into \"config\" directory" : "Cannot write into \"config\" directory",
    "Cannot write into \"apps\" directory" : "Cannot write into \"apps\" directory",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file.",
    "Cannot create \"data\" directory (%s)" : "Cannot create \"data\" directory (%s)",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s.",
    "Setting locale to %s failed" : "Setting locale to %s failed",
    "Please install one of these locales on your system and restart your webserver." : "Please install one of these locales on your system and restart your webserver.",
    "Please ask your server administrator to install the module." : "Please ask your server administrator to install the module.",
    "PHP module %s not installed." : "PHP module %s not installed.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP setting \"%s\" is not set to \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Adjusting this setting in php.ini will make ownCloud run again",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 is at least required. Currently %s is installed.",
    "To fix this issue update your libxml2 version and restart your web server." : "To fix this issue update your libxml2 version and restart your web server.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP modules have been installed, but they are still listed as missing?",
    "Please ask your server administrator to restart the web server." : "Please ask your server administrator to restart the web server.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 required",
    "Please upgrade your database version" : "Please upgrade your database version",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Please change the permissions to 0770 so that the directory cannot be listed by other users.",
    "Data directory (%s) is readable by other users" : "Data directory (%s) is readable by other users",
    "Data directory (%s) must be an absolute path" : "Data directory (%s) must be an absolute path",
    "Check the value of \"datadirectory\" in your configuration" : "Check the value of \"datadirectory\" in your configuration",
    "Data directory (%s) is invalid" : "Data directory (%s) is invalid",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Please check that the data directory contains a file \".ocdata\" in its root.",
    "Could not obtain lock type %d on \"%s\"." : "Could not obtain lock type %d on \"%s\".",
    "Storage unauthorized. %s" : "Storage unauthorised. %s",
    "Storage incomplete configuration. %s" : "Storage incomplete configuration. %s",
    "Storage connection error. %s" : "Storage connection error. %s",
    "Storage not available" : "Storage not available",
    "Storage connection timeout. %s" : "Storage connection timeout. %s"
},
"nplurals=2; plural=(n != 1);");
